-- 跨服时空
Lua_CrossServerWindow = class("Lua_CrossServerWindow", Lua_Window);
function Lua_CrossServerWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_CrossServerWindow";
	self.skinName = "CrossServerWindow_skin";
	self.layer = MainWinDefine.MAIN_WINDOW_LAYER;
	self.isFullSizeWin = true;
	self.isFullPaving = true;
	self.showWinBg = true;
	self.winBgPath = "/images/crossServer/xui_kfsk_bg_1.jpg";

	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_CrossServerWindow:buildPanel(go)
	self:superCall("buildPanel", go);

	self:addLuaEvent("SELECT_CROSS_ITEM", self, self.updateCrossItemInfo);
	self:addLuaEvent("CROSS_SERVER_INFO", self, self.updateCrossShowInfo);
end

function Lua_CrossServerWindow:buildShowItem()
	self:superCall("buildShowItem")

	self.showTipsDes = "";
	self.winBg.anchorValue = 4;
	self.winBg.pivotValue = 4;
	self.winBg:setLocation(0, 0 + GlobalVar.screenOffsetTopH, 0);
	self.titleTxt:setLangValue(202608);

	self.showEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_kfsk_cj", "ui_kfsk_cj", -2, 13 + GlobalVar.screenOffsetTopH);

	self.rewardList = Lua_DragList.new(self.content, 380, 102, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_CrossServerRewardCell, 115, 102, 1);
	self.rewardList:setRectAnchor(7);
	self.rewardList:setLocation(-52, 442);
	self.rewardList:setScale(0.82, 0.82);

	self.rectW = 700;
	self.rectH = 157;
	self.subRectW = self.rectW;
	self.subRectH = 157;
	self.subMinPos = -(self.subRectW - self.rectW) / 2;
	self.subMaxPox = -self.subMinPos;
	self.spaceW = 192;
	self.funcArr = Array();

	self.scrollContainer = UICreate.createScrollContainer(self.content, 0, 0, self.rectW, self.rectH);
	self.scrollContainer.horizontal = true;
	self.scrollContainer.vertical = false;
	self.scrollContainer.movementTypeValue = 1;
	self.scrollContainer.elasticity = 0.3;
	self.scrollContainer.inertia = true;
	self.scrollContainer.siblingIndex = 8;
	self.scrollContainer.anchorValue = 7;
	self.scrollContainer:setScrollAnchor(0.5, 0.5, 0.5, 0.5);
	self.scrollContainer:setScrollPivot(4);
	self.scrollContainer:addRectMask2D();
	self.scrollContainer:addMousDownFuntion(self, self.onMouseDownFun);
	self.scrollContainer:addMouseUpFuntion(self, self.onMouseUpFun);
	self.scrollContainer:setLocation(0, 219, 0);
	self.sub = self.scrollContainer.scrollContent;

	self.gotoBtn:addClickFuntion(self, self.onGoBtnClick);
	self.detaileBtn:addClickFuntion(self, self.onDetaileBtnClick);
	self.ruleBtn:addClickFuntion(self, self.onRuleBtnClick);

	self:showCrossWinInfo();
end

function Lua_CrossServerWindow:showCrossWinInfo()
	local arr = DataCenter.crossServerUtil.cCrossSeverInfo;
	local dataLen = arr:getSize();
	self.subRectW = dataLen * self.spaceW;
	self.subMinPos = -(self.subRectW - self.rectW) / 2;
	self.subMaxPox = -self.subMinPos;
	-- self.scrollContainer.horizontal = dataLen > 5;
	self.scrollContainer:setScrollSize(self.subRectW, self.subRectH);
	self.scrollContainer:setScrollPosition(self.subMaxPox, 0, 0);

	local startPosX = -(self.spaceW * dataLen) / 2 + self.spaceW / 2;
	local item;
	for i = 1, dataLen do
		item = Lua_CrossServerCell.new(self.sub);
		item.contentName = "Lua_CrossServerCell_" .. i;
		item:setRectSize(self.spaceW, self.subRectH);
		item:setLocation(startPosX + ((i - 1) % dataLen) * self.spaceW, 0, 0);
		item:onSelectionChange(false);
		item:setData(arr[i], i == dataLen);
		self.funcArr:add(item);
	end
	self.funcArr[1]:onPressClick();
	self.funcArr[1]:onSelectionChange(true);
	-- self:moveToIndex(1);
end

function Lua_CrossServerWindow:moveToIndex(idx)
	local targetPos = self.subMaxPox;
	for i = 1, idx - 1 do
		targetPos = targetPos - self.spaceW;
	end

	if targetPos > self.subMaxPox then
		targetPos = self.subMaxPox;
	elseif targetPos < self.subMinPos then
		targetPos = self.subMinPos;
	end
	self.scrollContainer:setScrollPosition(targetPos, 0, 0);
end

function Lua_CrossServerWindow:onMouseDownFun()
	self.startMouseX = CommonUtil.mousePositionX;
	self.startMouseY = CommonUtil.mousePositionY;
	self.startClickTime = getTime();
end

function Lua_CrossServerWindow:onMouseUpFun()
	local dx = CommonUtil.mousePositionX - self.startMouseX;
	local dy = CommonUtil.mousePositionY - self.startMouseY;
	if getTime() - self.startClickTime <= 0.3 and Mathf.Abs(dx) + Mathf.Abs(dy) < 4 then
		self:checkPressItem();
	end
end

function Lua_CrossServerWindow:checkPressItem()
	local winPos = LuaUtil.getTouchPosInverseObj(self.sub);
	local len = self.funcArr:getSize();
	for i = 1, len do
		if self.funcArr and self.funcArr[i] then
			self.funcArr[i]:onSelectionChange(false);
			if self.funcArr[i].isActive and self.funcArr[i]:checkInBound(winPos.x, winPos.y) then
				self.funcArr[i]:onPressClick();
				self.funcArr[i]:onSelectionChange(true);
			end
		end
	end
end

function Lua_CrossServerWindow:updateCrossItemInfo(data)
	self.data = data;
	self.nameTxt.text = data.name;
	self.conditionTxt.text = data.des;
	self.rewardList.canDrag = #data.reward_list > 3;
	self.rewardList:setArrayData(data.reward_list);

	Lua_ProxyManager.getProxy("Lua_CrossServerProxy"):sCrossServerInfo(data.id);
end

function Lua_CrossServerWindow:updateCrossShowInfo()
	if self.data.isOpened then
		self.showTipsDes = LanUtil.getValue(202602);
	else
		self.showTipsDes = DataCenter.crossServerData:openedDes(self.data.func_open_id);
	end
	self.openDesTxt.text = self.showTipsDes;
end

-- 前往
function Lua_CrossServerWindow:onGoBtnClick()
	if self.data.isOpened then
		DataCenter.funcPathUtil:gotoFunction(self.data.func_path_id, true);
	else
		OperateAlert.show(self.showTipsDes);
	end
end

-- 跨服详情
function Lua_CrossServerWindow:onDetaileBtnClick()
	Lua_WindowUtil.openWin("Lua_CrossServerTipsWindow", Lua_WinParam.ACTION_OPEN);
end

-- 帮助
function Lua_CrossServerWindow:onRuleBtnClick()
	local tipsData = { des = LanUtil.getValue(202607), posX = 145, posY = -250 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_CrossServerWindow:dispose()
	if self.showEff ~= nil then
		self.showEff:dispose();
		self.showEff = nil;
	end
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.funcArr ~= nil then
		self.funcArr:dispose();
		self.funcArr:clear();
		self.funcArr = nil;
	end
	if self.scrollContainer ~= nil then
		self.scrollContainer:dispose();
		self.scrollContainer = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end










Lua_CrossServerRewardCell = class("Lua_CrossServerRewardCell", Lua_ItemIconCell);
function Lua_CrossServerRewardCell:ctor(p)
	self:superCall("ctor", p);
end

function Lua_CrossServerRewardCell:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon:setScale(0.82, 0.82);
end

function Lua_CrossServerRewardCell:setData(data)
	self:superCall("setData", data);
	self.itemIcon:showNum(0);
end










Lua_CrossServerCell = class("Lua_CrossServerCell", Lua_DisplayObject);
function Lua_CrossServerCell:ctor(p)
	self:superCall("ctor", p, "CrossServerCell_skin");
end

function Lua_CrossServerCell:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_CrossServerCell:setData(data, isEnd)
	self._data = data;
	if data == nil then
		return;
	end

	local spriteName = data.isOpened and "xui_kfsk_scrollbar_1_f" or "xui_kfsk_scrollbar_1_b";
	self.barIcon:setAltas("cross_server_altas", spriteName);
	self.barIcon:SetDimensions(isEnd and 100 or 192, 16);
	self.icon:setAltas(data.atlas, data.sprite);
	self.icon:resetSize();
	self.icon:setGray(not data.isOpened);
	self.nameTxt.text = data.name;
	self.nameTxt:resetSize();
end

function Lua_CrossServerCell:checkInBound(posX, posY)
	local minX = self.centerPosX - self.w / 2;
	local maxX = self.centerPosX + self.w / 2;
	local minY = self.centerPosY - self.h / 2;
	local maxY = self.centerPosY + self.h / 2;
	return posX >= minX and posX <= maxX and posY >= minY and posY <= maxY;
end

function Lua_CrossServerCell:onPressClick()
	Lua_MsgUtil.callFunc("SELECT_CROSS_ITEM", self._data);
	return true;
end

function Lua_CrossServerCell:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);
	self.selectIcon:setEnable(bSelect);
end

function Lua_CrossServerCell:dispose()
	self._data = nil;
	self:superCall("dispose");
end